@@ -22,12 +22,13 @@ class FixedNode(GrammarTreeNode):
         return self.value
 
 class InterpolatedNode(GrammarTreeNode):
-    def __init__(self, resolver_key):
+    def __init__(self, resolver_key, *args):
         super().__init__()
         self.children = []
         self.resolver_key = resolver_key
+        self.args = args
 
     def __repr__(self):
-        children_repr = ", ".join(map(str, self.children))
+        children_repr = str(list(map(str, self.children)))
         resolver_repr = f"{self.resolver_key}:" if self.resolver_key else ""
         return f"${{{resolver_repr}{children_repr}}}"
\ No newline at end of file
