@@ -1,17 +1,19 @@
-from .util import apply, accessors_to_string, string_to_accessors
-from ..entities.wrappers import KCObject, KCList, KCDict, KCScalar
+from .util import apply, accessors_to_string
+from ..entities.wrappers import KCObject, KCList, KCDict
 from .convert import from_primitive
+from ..grammar.dotlist_grammar import parse_dotlist_entry
+from ..errors import DotlistGrammarError, AccessorGrammarError
 import yaml
 
-def from_dotlist(dotlist):
+def from_dotlist(dotlist, ignore_invalid_entries=False):
     result = dict(root=KCDict())
     for entry in dotlist:
-        accessor_value_split = entry.split("=")
-        if len(accessor_value_split) != 2:
-            from..errors import dotlist_entry_requires_equal_sign_error
-            raise dotlist_entry_requires_equal_sign_error()
-        accessor_string, value = accessor_value_split
-        accessors = string_to_accessors(accessor_string)
+        try:
+            accessors, value = parse_dotlist_entry(entry)
+        except (DotlistGrammarError, AccessorGrammarError):
+            if ignore_invalid_entries:
+                continue
+            raise
 
         # create missing parent objects
         prev_node = result["root"]
