@@ -1,3 +1,3 @@
 class ScalarResolver:
-    def resolve(self, value, root_node):
+    def resolve(self, value, root_node, trace):
         raise NotImplementedError
\ No newline at end of file
